/*
 * $Header: oraca.h,v 1030600.1 88/09/28 11:33:04 rcs Exp $ oraca.h Copyr (c) 1987 Oracle
 */

/* V1PCC10306,DISK$DEV6:[PCCSRC.DEFS.10306] */
/* Copyright (c) 1985 by Oracle Corporation. */
 
/*
NAME
  ORACA : Oracle Communications Area.
FUNCTION
  Contains no code. Provides supplementary communications to/from
  Oracle (in addition to standard SQLCA).
NOTES
  oracchf : Check cursor cache consistency flag. If set AND oradbgf
	    is set, then directs SQLLIB to perform cursor cache
	    consistency checks before every cursor operation
	    (OPEN, FETCH, SELECT, INSERT, etc.).
  oradbgf : Master DEBUG flag. Used to turn all DEBUG options
	    on or off.
  orahchf : Check Heap consistency flag. If set AND oradbgf is set,
	    then directs SQLLIB to perform heap consistency checks
	    everytime memory is dynamically allocated/free'd via
	    sqlalc/sqlfre/sqlrlc. MUST BE SET BEFORE 1ST CONNECT
	    and once set cannot be cleared (subsequent requests
	    to change it are ignored).
  orastxtf: Save SQL stmt text flag. If set, then directs SQLLIB
	    to save the text of the current SQL stmt in orastxt
	    (in VARCHAR format).
  orastxt : Saved len and text of current SQL stmt (in VARCHAR
	    format).
  orasfnm : Saved len and text of filename containing current SQL
	    stmt (in VARCHAR format).
  oraslnr : Saved line nr within orasfnm of current SQL stmt.
 
  Cursor cache statistics. Set after COMMIT or ROLLBACK. Each
  CONNECT'd DATABASE has its own set of statistics.
 
  orahoc  : Highest Max Open OraCursors requested. Highest value
	    for MAXOPENCURSORS by any CONNECT to this DATABASE.
  oramoc  : Max Open OraCursors required. Specifies the max nr
	    of OraCursors required to run this pgm. Can be higher
	    than orahoc if working set (MAXOPENCURSORS) was set
	    too low, thus forcing the PCC to expand the cache.
  oracoc  : Current nr of OraCursors used.
  oranor  : Nr of OraCursor cache reassignments. Can show the
	    degree of "thrashing" in the cache. Optimally, this
	    nr should be kept as low as possible (time vs space
	    optimization).
  oranpr  : Nr of SQL stmt "parses".
  oranex  : Nr of SQL stmt "executes". Optimally, the relation-
	    ship of oranex to oranpr should be kept as high as
	    possible.
 
 
  If the symbol ORACA_INIT is defined, then the ORACA will be
  statically initialized. Although this is not necessary in order
  to use the ORACA, it is a good pgming practice not to have
  unitialized variables. However, some C compilers/OS's don't
  allow automatic variables to be init'd in this manner. Therefore,
  if you are INCLUDE'ing the ORACA in a place where it would be
  an automatic AND your C compiler/OS doesn't allow this style
  of initialization, then ORACA_INIT should be left undefined --
  all others can define ORACA_INIT if they wish.
 
OWNER
  Clare
DATE
  10/19/85
MODIFIED
  Clare      02/20/86 - PCC [10101l] Feature: Heap consistency check.
  Clare      03/04/86 - PCC [10101r] Port: ORACA init ifdef.
  Clare      03/12/86 - PCC [10101ab] Feature: ORACA cuc statistics.
*/
 
#ifndef  ORACA
#define  ORACA	   1
 
struct	 oraca
	 {
	 char	   oracaid[8];	       /* Reserved			      */
	 long	   oracabc;	       /* Reserved			      */
 
/*	 Flags which are setable by User. */
 
	 long	   oracchf;	       /* <> 0 if "check cur cache consistncy"*/
	 long	   oradbgf;	       /* <> 0 if "do DEBUG mode checking"    */
	 long	   orahchf;	       /* <> 0 if "do Heap consistency check" */
	 long	   orastxtf;	       /* SQL stmt text flag		      */
#define  ORASTFNON 0		       /* = don't save text of SQL stmt       */
#define  ORASTFERR 1		       /* = only save on SQLERROR	      */
#define  ORASTFWRN 2		       /* = only save on SQLWARNING/SQLERROR  */
#define  ORASTFANY 3		       /* = always save 		      */
	 struct
	   {
	   unsigned short orastxtl;
	   char 	  orastxtc[70];
	   } orastxt;		       /* text of last SQL stmt 	      */
	 struct
	   {
	   unsigned short orasfnml;
	   char 	  orasfnmc[70];
	   } orasfnm;		       /* name of file containing SQL stmt    */
	 long	   oraslnr;	       /* line nr-within-file of SQL stmt     */
 
	 long	   orahoc;	       /* highest max open OraCurs requested  */
	 long	   oramoc;	       /* max open OraCursors required	      */
	 long	   oracoc;	       /* current OraCursors open	      */
	 long	   oranor;	       /* nr of OraCursor re-assignments      */
	 long	   oranpr;	       /* nr of parses			      */
	 long	   oranex;	       /* nr of executes		      */
	 };
 
struct oraca oraca
#ifdef ORACA_INIT
	 =
	 {
	 {'O','R','A','C','A',' ',' ',' '},
	 sizeof(struct oraca),
	 0,0,0,0,
	 {0,{0}},
	 {0,{0}},
	 0,
	 0,0,0,0,0,0
	 }
#endif
	 ;
 
#endif
 
/* end oraca.h */
